<?PHP
/**
 * Cart
 * 
 * 购物车类
 * 
 * @author  大白菜芯<php_netproject@yahoo.com.cn>
 * @package     Cart
 * @category    Cart
 * @license     PHP License
 * @access      public
 * @date  2004-08-21
 */
Class Cart{

 var $cartList;
 var $totalCount;   //商品总数量
 var $totalPrices;   //商品总金额
 /**
   * Cart Constructor
   * 
   * 类的构造函数，使购物车保持稳定的初始化状态 
   * 
   * @static 
   * @access  public 
   * @return  void   无返回值
   * @param   void   无参数
   */
  function Cart(){
	$this->totalCount = 0;
	$this->totalPrices = 0;
	$this->cartList = array();
  }
  
  // }}}
  // {{{ add($item)

  /**
   * 增加商品到当前购物车
   *
   * @access public
   * @param  array $item 商品信息（一维数组：array(商品ID,商品名称,商品单价,商品数量)）
   * @return array   返回当前购物车内商品的数组
   */
  function add($item){
  if(!is_array($item)||is_null($item))   return $this->_getArray($this->cartList);
  if(!is_numeric(end($item))||(!is_numeric(prev($item)))) {
  echo prev($item);
   echo "价格和数量必须是数字";
   return $this->_getArray($this->cartList);
  }
  reset($item); 
  $key = current($item);
  if($key=="")   return $this->_getArray($this->cartList);
  if($this->_isExists($key)){
    $this->cartList[$key]['count'] += end($item);
    $this->_stat();
  return $this->_getArray($this->cartList);
  }

  $this->cartList[$key]['gid']       = $key;
  $this->cartList[$key]['provider_id'] = next($item);
  $this->cartList[$key]['Js_price']    = next($item);
  $this->cartList[$key]['goodsname']   = next($item);
  $this->cartList[$key]['nocarriage']  = next($item);
  $this->cartList[$key]['smallimg']    = next($item);
  $this->cartList[$key]['temp_price']  = next($item);
  $this->cartList[$key]['price']       = next($item);
 // $this->cartList[$key]['member_price']     = next($item);
  $this->cartList[$key]['count']     = next($item);
  $this->_stat();
 return $this->_getArray($this->cartList);
 }

 // }}}
 // {{{ add($item)


 function remove($key="",$count=""){
  if($key=="") {
   $this->cartList = array();
   return true;
  }
  if(!array_key_exists($key,$this->cartList)) return false;
  if($count==""){ //移去这一类商品
   unset($this->cartList[$key]);
  }else{ //移去$count个商品
   $this->cartList[$key]['count'] -= $count;
   if($this->cartList[$key]['count']<=0) unset($this->cartList[$key]);
  }
  $this->_stat();
  return $this->_getArray($this->cartList);
 }

// }}}
 // {{{ modi($key,$value)

/**
 * 修改购物车内商品ID为 $key 的商品的数量为 $value
 *
 * @access public
 * @param  string $key 商品ID
 * @param  int $value 商品数量
 * @return array  返回当前购物车内商品的数组;
 */
 function modi($key,$value){
  if(!$this->_isExists($key)) return $this->_getArray($this->cartList); //
  if($value<=0){     // value び场埃
   unset($this->cartList[$key]);
   $this->_stat();
   return $this->_getArray($this->cartList);
  }
  $this->cartList[$key]['count'] = $value;
  $this->_stat();
  return $this->_getArray($this->cartList);
 }
 /**
 * 返回当前购物车内商品的数组
 *
 * @access public
 * @return array  返回当前购物车内商品的数组;
 */
 function getCart(){
 	$this->_stat();
	//echo "<hr>";
	//print_r($this->cartList);
	//echo "<hr>";
    return $this->_getArray($this->cartList);
 }
 // }}}
 // {{{ _isExists($key)

/**
 * 判断当前购物车中是否存在商品ID号为$key的商品
 *
 * @access private
 * @param  string $key 商品ID
 * @return bool   true or false;
 */
 function _isExists($key){
    if(isset($this->cartList[$key])&&!empty($this->cartList[$key])&&array_key_exists($key,$this->cartList))
    return true;
    return false;
 }
 // }}}
 // {{{ _getArray()

/**
 * 重新排列购物车内的产品，以便于smarty读取
 *
 * @access private
 * @return array  返回已经排列好的购物车内的商品;
 */
 function _getArray($array){
	$myCart = array();
	foreach($array as $item)
    array_push($myCart,$item);
    return $myCart;
 }
 // }}}
 // {{{ isEmpty()

/**
 * 判断当前购物车是否为空，即没有任何商品
 *
 * @access public
 * @return bool   true or false;
 */
 function isEmpty(){
	return !count($this->cartList);
 }

  function Empty_array(){
	return $this->cartList=array();
 }
 // }}}
 // {{{ _stat()

/**
 * 取得部分统计信息
 *
 * @access private
 * @return bool  true or false;
 */

 function _stat(){
	if($this->isEmpty()) {
  	$this->totalCount=0;
  	$this->totalPrices=0;
    return false;
  }
    unset($this->totalCount);
  	unset($this->totalPrices);
  foreach($this->cartList as $item){
  	$c=@end($item);
  	$p=@prev($item);
   $this->totalCount  += $c;
   $this->totalPrices += $p*$c;
  }
  return true;
 }

/*
 // }}}
 // {{{ totalPrices()

/**
 * 取得当前购物车所有商品的总金额
 *
 * @access public
 * @return float  返回金额;
 */
 function getTotalPrices(){
  if($this->_stat()){
   return $this->totalPrices;
  }else{
 return 0;
  }
 }
 // }}}
 // {{{ isEmpty()

/**
 * 取得当前购物车所有商品的总数量和
 *
 * @access public
 * @return int ;
 */
 function getTotalCount(){
  if($this->_stat()){
   return $this->totalCount;  }
   else{
 return 0;
   }
 }


}

?>